---
known_issue: KI_80_82_13_35
issue_title: full option list on describe with prefix
---


`CompType.DescribeArgs` is used together with `RunMode.InvocationMode` to use tangent token (FS_23_62_89_43).

However, when arg value is incomplete, there is no reduction of options shown in description:

```sh
some_command goto host pro|
```

Actual:

```
ClassFunction:
  ActionType: goto [ExplicitPosArg]
  ObjectSelector: host [ExplicitPosArg]
ClassCluster:
  *CodeMaturity: ? dev qa prod
  ...
```

Expected:

```
ClassFunction:
  ActionType: goto [ExplicitPosArg]
  ObjectSelector: host [ExplicitPosArg]
ClassCluster:
  *CodeMaturity: ? prod
  ...
```

If it was `RunMode.InvocationMode`, the suggestion is as expected.

*   So far, `argrelay` does not allow incomplete arg values in case of multiple options on invocation.
*   But reducing show options for given prefix in on `CompType.DescribeArgs` is also not a completion.

This is a special case to handle. 
